=======================
OpenStack Image Manager
=======================

With this script it is possible to easily manage and keep up to date a 
large number of images on an OpenStack enviroment.

.. toctree::
   :maxdepth: 2

   requirements
   notes
   configuration
   contribute
   usage
